﻿using System.Collections.Generic;
using System.Linq;
using System.Net;
using System.Threading.Tasks;
using Microsoft.AspNetCore.Mvc;
using Microsoft.EntityFrameworkCore;
using TeamSample.Data;

namespace TeamSample.Api.Controllers
{
    [Route("/api/[controller]")]
    public class PositionsController : Controller
    {
        private readonly TeamSampleDbContext _context;

        public PositionsController(TeamSampleDbContext context)
        {
            _context = context;
        }

        [HttpGet]
        public async Task<IEnumerable<Models.Position>> Get()
        {
            var positions = await _context.Positions
                .Select(p => new Models.Position
                {
                    Id = p.Id,
                    Name = p.Name,
                    Abbreviation = p.Abbreviation
                })
                .ToListAsync();

            return positions;
        }

        [HttpGet("[action]/{abbreviation}")]
        public async Task<string> NameFromAbbreviation(string abbreviation)
        {
            var position = await _context.Positions
                .Where(_ => _.Abbreviation == abbreviation)
                .Select(_ => _.Name)
                .FirstOrDefaultAsync();

            if (string.IsNullOrWhiteSpace(position))
            {
                Response.StatusCode = (int) HttpStatusCode.NoContent;
                return null;
            }

            return position;
        }

        [HttpGet("[action]/{abbreviation}")]
        public async Task<Models.Position> FromAbbreviation(string abbreviation)
        {
            var result = await _context.Positions
                .Where(_ => _.Abbreviation == abbreviation)
                .Select(p => new Models.Position {Id = p.Id, Name = p.Name})
                .FirstOrDefaultAsync();

            if (result == null)
            {
                Response.StatusCode = (int)HttpStatusCode.NoContent;
                return null;
            }

            return result;
        }
    }
}