﻿using Microsoft.AspNetCore.Builder;
using Microsoft.AspNetCore.Hosting;
using Microsoft.Extensions.Configuration;
using Microsoft.Extensions.DependencyInjection;
using TeamSample.Data;
using Microsoft.EntityFrameworkCore;
using Newtonsoft.Json;

namespace TeamSample.Api
{
    public class Startup
    {
        public Startup(IConfiguration configuration)
        {
            Configuration = configuration;
        }

        public IConfiguration Configuration { get; }

        public void ConfigureServices(IServiceCollection services)
        {
            var connectionString = Configuration.GetConnectionString("TeamSample");
            services.AddDbContext<TeamSampleDbContext>(_ => _.UseSqlServer(connectionString));

            var mvcBuilder = services.AddMvc();

            mvcBuilder.AddJsonOptions(o =>
            {
                o.SerializerSettings.DefaultValueHandling = DefaultValueHandling.IgnoreAndPopulate;
            });
        }

        public void Configure(IApplicationBuilder app, IHostingEnvironment env)
        {
            if (env.IsDevelopment())
            {
                app.UseDeveloperExceptionPage();
            }

            using (var scope = app.ApplicationServices.CreateScope())
            {
                var services = scope.ServiceProvider;
                var context = services.GetRequiredService<TeamSampleDbContext>();
                TeamSampleDbInitializer.Initialize(context);
            }

            app.UseMvc();
            
        }
    }
}
