﻿using Microsoft.EntityFrameworkCore;
using System.Linq;
using TeamSample.Data;
using TeamSample.Entities;

namespace TeamSample.Api
{
    internal static class TeamSampleDbInitializer
    {
        private static object _lock = new object();
        private static bool _initialized = false;

        internal static void Initialize(TeamSampleDbContext context)
        {
#if DEBUG
            if (!_initialized)
            {
                lock (_lock)
                {
                    if (_initialized == true)
                        return;

                    _initialized = true;

                    InitializeDatabase(context);

                }
            }
#endif
        }

        private static void InitializeDatabase(TeamSampleDbContext context)
        {
            context.Database.Migrate();

            var positionsExist = context.Positions.Any();

            if (!positionsExist)
            {
                context.Positions.Add(new Position { Abbreviation = "1B", Name = "1st Base" });
                context.Positions.Add(new Position { Abbreviation = "2B", Name = "2nd Base" });
                context.Positions.Add(new Position { Abbreviation = "3B", Name = "3rd Base" });
                context.Positions.Add(new Position { Abbreviation = "SS", Name = "Shortstop" });
                context.Positions.Add(new Position { Abbreviation = "P", Name = "Pitcher" });
                context.Positions.Add(new Position { Abbreviation = "C", Name = "Catcher" });
                context.Positions.Add(new Position { Abbreviation = "LF", Name = "Left Field" });
                context.Positions.Add(new Position { Abbreviation = "CF", Name = "Center Field" });
                context.Positions.Add(new Position { Abbreviation = "RF", Name = "Right Field" });
                context.Positions.Add(new Position { Abbreviation = "DH", Name = "Designated Hitter" });

                context.SaveChanges();
            }
        }
    }
}
